/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or http://eu-egee.org/license.html
 * 
 * Authors: 
 *      Paolo Badino <Paolo.Badino@cern.ch>>
 *      Akos Frohner <Akos.Frohner@cern.ch>
 *      Peter Kunszt <Peter.Kunszt@cern.ch>
 *      Gavin McCance <Gavin.McCance@cern.ch>
 *      Krzysztof Nienartowicz <Krzysztof.Nienartowicz@cern.ch>
 *      Ricardo Rocha <Ricardo.Rocha@cern.ch>
 *      Jozsef Kovacs <smith@lutra.sztaki.hu>
 *      Daniel Rodrigues <Daniel.Rodrigues@cern.ch> 
 */


package org.glite.data.catalog.service;

/**
 * Attribute contains a name, a value and a type. It is the object with which items/entries in the
 * Metadata Catalog can be associated.
 * 
 * <p>An attribute in the Metadata Catalog is unique in the sense that the combination name/type MUST
 * be unique. An attribute MUST have only one type, even when associated with more than one schema.</p>
 * 
 * <p>All values stored inside an Attribute are encoded as strings, even if the backend is storing them
 * using a different type. The type of an Attribute is a hint on the content of this string, so that
 * the backend can optimize storage.</p> 
 * 
 * @see org.glite.data.catalog.service.meta
 * @see org.glite.data.catalog.service.meta.MetadataBase
 * @see org.glite.data.catalog.service.meta.MetadataCatalog
 * @see org.glite.data.catalog.service.meta.MetadataSchema 
 */

public class Attribute {
    
    /**
     * <code>name</code> is the Metadata Catalog attribute's name. It is a string that describes the
     * attribute. 
     */
    public String name;
    
    /**
     * <code>value</code> is the Metadata Catalog attribute's value. All values are always encoded as
     * strings, even if the backend is storing them in a different format.
     */
    public String value;
    
    /**
     * <code>type</code> is the Metadata Catalog attribute's type. It is a hint for the backend to know
     * which data type to use for storage.
     */
    public String type;
}
