/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://public.eu-egee.org/partners/ for details on 
 * the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 *
 * Authors: 
 *      Paolo Badino <Paolo.Badino@cern.ch>>
 *      Akos Frohner <Akos.Frohner@cern.ch>
 *      Peter Kunszt <Peter.Kunszt@cern.ch>
 *      Gavin McCance <Gavin.McCance@cern.ch>
 *      Krzysztof Nienartowicz <Krzysztof.Nienartowicz@cern.ch>
 *      Ricardo Rocha <Ricardo.Rocha@cern.ch>
 *      Jozsef Kovacs <smith@lutra.sztaki.hu>
 *      Daniel Rodrigues <Daniel.Rodrigues@cern.ch>
 */
package org.glite.data.catalog.service.storageindex;

import org.glite.data.catalog.service.*;

/**
 * An indexing interface from which the client can get a list of SEs
 * where certain files are located.
 *
 * @stereotype simple-interface
 */
public interface SEIndex extends ServiceBase {
    
    //  commands updating the catalog
    
    /**
     * List all SEs where the LFN has a replica.
     *
     * @param lfn   The logical filename
     * @throws org.glite.data.catalog.service.AuthorizationException  No access right to list SEs.
     * @throws org.glite.data.catalog.service.NotExistsException  No such lfn found.
     */
    public String[] listSEbyLFN(String lfn) throws InternalException, AuthorizationException, NotExistsException;

    /**
     * List all SEs where the GUID has a replica.
     *
     * @param guid   The GUID
     * @throws org.glite.data.catalog.service.AuthorizationException  No access right to list SEs.
     * @throws org.glite.data.catalog.service.NotExistsException  No such guid found.
     */
    public String[] listSEbyGUID(String guid) throws InternalException, AuthorizationException, NotExistsException;

}
